@@ -13,8 +13,7 @@ from matplotlib import cm
 # from mud import __version__ as __mud_version__
 from mud.funs import map_sol, mud_sol, updated_cov
 from mud.norm import full_functional, norm_data, norm_input, norm_predicted
-from mud.util import transform_linear_setup
-from scipy.linalg import null_space
+from mud.util import transform_linear_setup, null_space
 
 # from mud_examples import __version__
 from mud_examples.utils import make_2d_unit_mesh
@@ -160,7 +159,7 @@ def main_dim(args):
     plt.legend(['MUD', 'MAP', 'Least Squares'], fontsize=fsize)
     # plt.annotate(f'Slope={slope:1.4f}', (4,4/7), fontsize=32)
     plt.savefig(f'{fdir}/{prefix}-convergence.png', bbox_inches='tight')
-    plt.close()
+    plt.close('all')
     # plt.show()
 
     # plt.imshow(initial_cov)
@@ -181,7 +180,7 @@ def main_dim(args):
     # # ax.set(yscale='log')
     # ax.view_init(15, 15)
     # plt.savefig(f'lin/{prefix}-surface-error.png', bbox_inches='tight')
-    # plt.close()
+    # plt.close('all')
     # # plt.show()
 
     # # # Convergence in Predictions
@@ -209,7 +208,7 @@ def main_dim(args):
     # plt.legend(['mud', 'map', 'least squares'], fontsize=fsize, loc='lower left')
     # # plt.annotate(f'Slope={slope:1.4f}', (4,4), fontsize=24)
     # plt.savefig(f'lin/{prefix}-convergence-dimension-out.png', bbox_inches='tight')
-    # plt.close()
+    # plt.close('all')
     # # plt.show()
 
 
@@ -327,7 +326,7 @@ def main_rank(args):
     plt.legend(['MUD', 'MAP', 'Least Squares'], fontsize=fsize)
     # plt.annotate(f'Slope={slope:1.4f}', (4,4/7), fontsize=32)
     plt.savefig(f'{fdir}/{prefix}-convergence.png', bbox_inches='tight')
-    plt.close()
+    plt.close('all')
     # plt.show()
 
     # plt.imshow(initial_cov)
@@ -600,10 +599,10 @@ def main_meas(args):
     # plt.legend()
     if save:
         plt.savefig(f'{fdir}/{prefix}-convergence.png', bbox_inches='tight')
-        plt.close()
+        plt.close('all')
     else:
         plt.show()
-        plt.close()
+        plt.close('all')
 
     plt.figure(figsize=(10, 10))
     plt.yscale('log')
@@ -632,10 +631,10 @@ def main_meas(args):
 
     if save:
         plt.savefig(f'{fdir}/{prefix}-sd-convergence.png', bbox_inches='tight')
-        plt.close()
+        plt.close('all')
     else:
         plt.show()
-        plt.close()
+        plt.close('all')
 
 
 def main_meas_var(args):
@@ -749,10 +748,10 @@ def main_meas_var(args):
     # plt.legend(['MUD', 'Least Squares'], fontsize=fsize)
     if save:
         plt.savefig(f'{fdir}/{prefix}-convergence.png', bbox_inches='tight')
-        plt.close()
+        plt.close('all')
     else:
         plt.show()
-        plt.close()
+        plt.close('all')
 
 
 def main(args):
@@ -957,7 +956,7 @@ def contour_example(
             fdir = '/'.join(figname.split('/')[:-1])
             check_dir(fdir)
         plt.savefig(figname, dpi=300)
-        plt.close()
+        plt.close('all')
 
 #     plt.title('Predicted Covariance: {}'.format((A@initial_cov@A.T).ravel() ))
     # plt.show()
